# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: blickfeld/hardware/config/identification.proto
# plugin: python-betterproto
from dataclasses import dataclass

import blickfeld_qb2.betterproto as betterproto
import blickfeld_qb2.betterproto.lib.google.protobuf as betterproto_lib_google_protobuf


@dataclass(eq=False, repr=False)
class Identification(betterproto.Message):
    """
    Identification message of the Qb2 device. It aggregates all hardware
    components.
    """

    serial_number: str = betterproto.string_field(1)
    """
    This is the top-level product identification. The serial number will be
    used as label and API identifier for the device.
    """
