# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: blickfeld/diagnostics/options.proto
# plugin: python-betterproto
from dataclasses import dataclass

import blickfeld_qb2.betterproto as betterproto
import blickfeld_qb2.betterproto.lib.google.protobuf as betterproto_lib_google_protobuf


@dataclass(eq=False, repr=False)
class SoftwareModuleEnumValueOption(betterproto.Message):
    """Options for the software modules"""

    systemd_unit_name: str = betterproto.string_field(1)
    """Name of the systemd unit corresponding to this software module"""
